@@ -10,24 +10,26 @@ use App::Pods2Site::Util qw(slashify);
 sub _getCategoryTOC
 {
 	my $self = shift;
-	my $category = shift;
-	my $n2h = shift;
+	my $groupName = shift;
+	my $podInfo = shift;
 	my $sitedir = shift;
 	
 	my $toc = '';
 	my %tree;
-	foreach my $name (keys(%$n2h))
+	foreach my $podName (sort(keys(%$podInfo)))
 	{
 		my $treeloc = \%tree;
-		for my $level (split(/::/, $name))
+		for my $level (split(/::/, $podName))
 		{
 			$treeloc->{$level} = {} unless exists($treeloc->{$level});
 			$treeloc = $treeloc->{$level};
 		}
 	}
-	$self->_genRefs($sitedir, \$toc, $n2h, \%tree);
+	$self->_genRefs($sitedir, \$toc, $podInfo, \%tree);
 	chomp($toc);
-	$toc = qq(<strong>$category</strong><br/><br/>\n$toc<br/><hr/>) if $toc;
+	$toc = qq(<strong>$groupName</strong><br/><br/>\n$toc<br/><hr/>) if $toc;
+	
+	return $toc;
 }
 
 sub _genRefs
@@ -35,7 +37,7 @@ sub _genRefs
 	my $self = shift;
 	my $sitedir = shift;
 	my $ref = shift;
-	my $n2h = shift;
+	my $podInfo = shift;
 	my $treeloc = shift;
 	my $depth = shift || 0;
 	my $n = shift;
@@ -46,7 +48,7 @@ sub _genRefs
 	{
 		$r = "${n}::";
 		$$ref .= ('&emsp;' x ($depth - 1)) if $depth > 1;
-		my $p = $n2h->{$n};
+		my $p = $podInfo->{$n}->{htmlfile};
 		if ($p)
 		{
 			$p =~ s#\Q$sitedir\E.##;
@@ -63,7 +65,7 @@ sub _genRefs
 		my $subn = "$r$subnp";
 		
 		$depth++;
-		$self->_genRefs($sitedir, $ref, $n2h, $treeloc->{$subnp}, $depth, $subn, $subnp);
+		$self->_genRefs($sitedir, $ref, $podInfo, $treeloc->{$subnp}, $depth, $subn, $subnp);
 		$depth--;
 	}
 }
